@@ -11,9 +11,11 @@ class PortMapper(BaseMapper):
         return "int"
 
     def get_expected_input_format(self):
-        return "from/to or p1 p2 p3"
+        return "from/to or p1 p2 p3 or all"
 
     def map(self, value):
+        if value == "all":
+            return [p for p in range(1, 65535+1)]
         # parse if it's a range (from-to)
         port_range = re.search("^([0-9]+)\-([0-9]+)$", value)
 
